@@ -132,14 +132,25 @@ target_sda <- function(data,
   ald_by_sector <- ald %>%
     aggregate_excluding(c("technology", "plant_location", "country_of_domicile"))
 
-  loanbook_with_weighted_emission_factors <- calculate_weighted_emission_factor(
-    data,
-    ald = ald_by_sector,
-    use_credit_limit = use_credit_limit,
-    by_company = by_company
-  )
+  data <- inner_join(data, ald_by_sector, by = ald_columns())
 
-  if (identical(nrow(loanbook_with_weighted_emission_factors), 0L)) {
+  if (by_company) {
+    data <- data %>%
+      summarize_weighted_emission_factor(
+        !!!rlang::syms("name_ald"),
+        use_credit_limit = use_credit_limit
+      )
+  } else {
+    data <- data %>%
+      summarize_weighted_emission_factor(
+        use_credit_limit = use_credit_limit
+      )
+  }
+
+  data <- data %>%
+    rename(sector = .data$sector_ald)
+
+  if (identical(nrow(data), 0L)) {
     warn("Found no match between loanbook and ald.", class = "no_match")
     return(empty_target_sda_output())
   }
@@ -171,7 +182,7 @@ target_sda <- function(data,
   )
 
   loanbook_targets <- compute_loanbook_targets(
-    loanbook_with_weighted_emission_factors,
+    data,
     adjusted_scenario_with_p,
     !!!rlang::syms(target_summary_groups)
   )
@@ -182,7 +193,7 @@ target_sda <- function(data,
   }
 
   format_and_combine_output(
-    loanbook_with_weighted_emission_factors,
+    data,
     corporate_economy,
     loanbook_targets,
     adjusted_scenario,
@@ -226,25 +237,6 @@ maybe_add_name_ald <- function(data, by_company = FALSE) {
   return(out)
 }
 
-calculate_weighted_emission_factor <- function(data,
-                                               ald,
-                                               use_credit_limit = FALSE,
-                                               by_company = FALSE) {
-  summary_groups <- maybe_add_name_ald(c("sector_ald", "year"), by_company)
-
-  data %>%
-    inner_join(ald, by = ald_columns()) %>%
-    add_weighted_loan_emission_factor(
-      use_credit_limit = use_credit_limit
-    ) %>%
-    group_by(!!!rlang::syms(summary_groups)) %>%
-    summarize(
-      emission_factor_projected = sum(.data$weighted_loan_emission_factor)
-    ) %>%
-    ungroup() %>%
-    rename(sector = .data$sector_ald)
-}
-
 calculate_market_average <- function(data) {
   data %>%
     group_by(.data$sector, .data$year) %>%
